@@ -20,11 +20,11 @@
 
 #pragma once
 
-struct help_flag {
+typedef struct {
     const char *optname;
     const char *argname;
     const char *description;
-};
+} help_flag_t;
 
 typedef enum {
     help_usage,
@@ -34,7 +34,7 @@ typedef enum {
 struct help {
     const char *progname;
     const char *args;
-    const struct help_flag *flags;
+    const help_flag_t *flags;
 };
 
 void show_help(help_type_t type, const struct help *, const char *warning);
