@@ -599,8 +599,10 @@ ofmt_t ofmt_new(void)
     radix_t resolvers_map;
 
     ofmt = malloc(sizeof(struct ofmt));
-    if (!ofmt)
+    if (!ofmt) {
+        warn("malloc");
         return NULL;
+    }
 
     resolvers_map = radix_new();
     if (!resolvers_map) {
