@@ -24,12 +24,14 @@
 
 int placeholders_setup(ofmt_t);
 
+/* This struct collects additional information that gets copied in the
+ * opaque structure within a ofmt_t object.  This information is
+ * ultimately available to the placeholder resolution functions
+ * defined in 'placeholders.c'. */
 typedef struct {
-    /* This struct collects additional information that gets copied in the
-     * opaque structure within a ofmt_t object.  This information is
-     * ultimately available to the placeholder resolution functions
-     * defined in 'placeholders.c'. */
     unsigned incremental_id;
+    const char *feed_title;
+    const char *feed_identifier;
 } placeholder_extra_t;
 
 void placeholders_set_extra(ofmt_t, const placeholder_extra_t *extra);
